@@ -61,4 +61,14 @@ IRT.irfprob.rm.sdt <- IRT.irfprob.gom
 ########################################################
 # irfprob prob.guttman
 IRT.irfprob.prob.guttman <- IRT.irfprob.gom
-########################################################
\ No newline at end of file
+########################################################
+# irfprob xxirt
+IRT.irfprob.xxirt <- function( object , ... ){    
+    ll <- object$probs_items
+    attr(ll,"theta") <- object$Theta
+	attr(ll,"prob.theta") <- object$probs_Theta
+	attr(ll,"G") <- object$G			
+    return(ll)	
+        }
+########################################################
+
