@@ -9,7 +9,7 @@
 	K <- length(b.cat)	
 	prob1 <- prob <- array( 1 , dim=c(TP,I,K+1) )
 	for (kk in 1:K){
-		prob1[,,kk+1] <- plogis( theta + matrix( b , nrow=TP , ncol=I, byrow=TRUE) + b.cat[kk] )
+		prob1[,,kk+1] <- stats::plogis( theta + matrix( b , nrow=TP , ncol=I, byrow=TRUE) + b.cat[kk] )
 		prob[,,kk] <- prob1[,,kk]-prob1[,,kk+1]
 				 }
 	kk <- K+1
