@@ -7,6 +7,6 @@ mirt.wrapper.itemplot <- function( mirt.obj , ask=TRUE , ...){
         # ii <- 1
         main <- paste0("Trace Lines of Item " , colnames( mirt.obj@Data$data )[ii] )
         print( mirt::itemplot(mirt.obj,item=ii , main=main , ...) )
-        par(ask=ask)
+        graphics::par(ask=ask)
                 }
         }
\ No newline at end of file
