@@ -215,7 +215,7 @@ noharm.sirt <- function(dat,weights=NULL,Fval=NULL,Fpatt=NULL,
 	# rotated solution
 	
 	if (model.type=="EFA"){	
-		m1 <- promax(res$loadings)		
+		m1 <- stats::promax(res$loadings)		
 		p1 <- matrix( 0 , nrow=I,D)
 		for (dd in 1:D){ p1[,dd] <- m1$loadings[,dd] }
 		colnames(p1) <- colnames(Pval)
