@@ -2,9 +2,8 @@
 
 ###########################################################################
 # simulation of Rasch copula model
-##NS export(sim.rasch.dep)
 sim.rasch.dep <- function( theta , b , itemcluster , rho ){
-    probmat <- plogis( outer( theta , b , "-" ) )
+    probmat <- stats::plogis( outer( theta , b , "-" ) )
     I <- length(b)
 	n <- length(theta)
     # covariance matrix of dependencies
@@ -18,7 +17,7 @@ sim.rasch.dep <- function( theta , b , itemcluster , rho ){
                         if ( ii != jj ){ cov.dep[ii,jj] <- rho[cc] 
                                 } } }
             }	
-    random.gen <- pnorm( mvrnorm( n , mu = rep(0,I) , Sigma = cov.dep ) )
+    random.gen <- stats::pnorm( MASS::mvrnorm( n , mu = rep(0,I) , Sigma = cov.dep ) )
     dat <- 1 * ( probmat > random.gen )
 	colnames(dat) <- paste( "I" , substring(100+1:I,2) , sep="")	
     return(dat)
