@@ -2,9 +2,10 @@
 
 xxirt_ThetaDistribution_extract_freeParameters <- function( customTheta ){
 		est <- customTheta$est
-		if ( sum(est) == 0 ){
-			par1 <- NULL } else {
+		if ( base::sum(est) == 0 ){
+			par1 <- NULL 
+		} else {
 			par1 <- customTheta$par[ est ]
-					}
-		return(par1)
-			}
\ No newline at end of file
+		}
+		base::return(par1)
+}
\ No newline at end of file
